@@ -1,26 +1,3 @@
-		guint 			beecon_lt0_BgRGB;
-		guint 			beecon_eq0_BgRGB;
-		guint 			beecon_eq1_BgRGB;
-		guint 			beecon_gt2_BgRGB;
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 /*
 
 desktop-cmd-exec.c - Desktop Command Execution Widget
@@ -494,14 +471,13 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 		g_key_file_set_string_list(keyFile, "config", "c_commands", (const gchar **)(self->priv->c_commands),self->priv->c_size);
 	}
 
-	g_key_file_set_double (keyFile, self->priv->widgetID, "widthRatio", self->priv->widthRatio);
-	g_key_file_set_double (keyFile, self->priv->widgetID, "heightRatio", self->priv->heightRatio);
-
 	if(self->priv->instanceTitle != NULL && self->priv->instanceCmd != NULL)
 	{
 		g_key_file_set_string (keyFile, self->priv->widgetID, "instanceTitle", self->priv->instanceTitle);
 		g_key_file_set_string (keyFile, self->priv->widgetID, "instanceCmd", self->priv->instanceCmd);
 	}
+	g_key_file_set_double (keyFile, self->priv->widgetID, "widthRatio", self->priv->widthRatio);
+	g_key_file_set_double (keyFile, self->priv->widgetID, "heightRatio", self->priv->heightRatio);
 	g_key_file_set_boolean (keyFile, self->priv->widgetID, "showCmdLabel", self->priv->showCmdLabel);//AP2
 	g_key_file_set_integer (keyFile, self->priv->widgetID, "cmdFontName", self->priv->cmdFontName);//AP1
 	g_key_file_set_double (keyFile, self->priv->widgetID, "cmdFontSize", self->priv->cmdFontSize);//AP1
